bayespy.inference.vmp.nodes.gaussian.GaussianDistribution.compute_logpdf
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianDistribution.compute_logpdf